<template>
    <StudentLayout>
        <div class="container mt-4">
            <h3 class="mb-4">{{ pageTitle }}</h3>

            <div class="d-flex align-items-center gap-3 mb-4">
                <BaseInput
                    v-model="searchInput"
                    class="w-25"
                    placeholder="Cari Lowongan"
                    label="Pencarian"
                />
                <BaseDropDown
                    v-model="filterCompany"
                    class="w-25"
                    label="Perusahaan"
                    placeholder="-- Pilih Perusahaan --"
                    :options="company.map(company => ({
                        label: company.name,
                        value: company.id
                    }))"
                />
            </div>

            <div v-if="filterStatus === 'applied'">
                <table class="table table-striped">
                    <thead>
                    <tr>
                        <th>Perusahaan</th>
                        <th>Nama Lowongan</th>
                        <th>Lokasi</th>
                        <th>Tipe</th>
                        <th>Tanggal Posting</th>
                        <th>Status</th>
                        <th>Aksi</th>
                    </tr>
                    </thead>
                    <tbody>
                    <tr v-for="job in vacancies.data" :key="job.id">
                        <td>
                            <span class="d-flex align-items-center">
                                <img
                                    :src="`/storage/uploads/company/${job.company.logo}`"
                                    alt="Logo"
                                    class="rounded-circle me-2"
                                    width="30"
                                    height="30"
                                />
                                {{ job.company.name }}
                            </span>

                        </td>
                        <td>{{ job.title }}</td>
                        <td>{{ job.location }}</td>
                        <td>{{ job.type }}</td>
                        <td>{{ formatDate(job.created_at) }}</td>
                        <td>
                                <span class="badge rounded-1" :class="{
                                    'bg-warning': job.applications[0].status === 'applied',
                                    'bg-info': job.applications[0].status === 'interviewed',
                                    'bg-success': job.applications[0].status === 'hired',
                                    'bg-danger': job.applications[0].status === 'rejected'
                                }">
                                    {{ job.applications[0].status }}
                                </span>
                        </td>

                        <td>
                            <Link :href="`/user/job/${job.id}`" class="btn btn-primary btn-sm rounded-1">
                                Detail
                            </Link>
                        </td>
                    </tr>
                    </tbody>
                </table>
            </div>

            <div v-else class="row">
                <div
                    class="col-md-6 col-lg-4 mb-4"
                    v-for="job in vacancies.data"
                    :key="job.id"
                >
                    <Link class="card shadow-sm" :href="`/user/job/${job.id}`">
                        <div class="card-body">
                            <img
                                :src="`/storage/uploads/vacancy/${job.poster}`"
                                alt="Poster"
                                class="img-fluid mb-3"
                            />
                            <div class="d-flex align-items-center mb-3">
                                <img
                                    :src="`/storage/uploads/company/${job.company.logo}`"
                                    alt="Logo"
                                    class="rounded-circle me-3"
                                    width="50"
                                    height="50"
                                />
                                <div>
                                    <h5 class="card-title mb-0">{{ job.title }}</h5>
                                    <small class="text-muted">{{ job.company.name }}</small>
                                </div>
                            </div>
                            <p class="card-text mb-1">
                                <strong>Lokasi:</strong> {{ job.location }}
                            </p>
                            <p class="card-text mb-1">
                                <strong>Tipe:</strong> {{ job.type }}
                            </p>
                            <span
                                class="badge"
                                :class="job.is_easy_apply ? 'bg-purple-600' : 'bg-gray-600'"
                            >
                                {{ job.is_easy_apply ? 'Lamaran Mudah' : 'Lamaran Biasa' }}
                            </span>
                        </div>
                    </Link>
                </div>
            </div>
            <PaginationLink :links="vacancies.links" class="mt-3"/>
        </div>
    </StudentLayout>
</template>

<script setup>
import { computed, ref, watch } from 'vue';
import StudentLayout from '@/Layouts/StudentLayout.vue';
import debounce from "lodash/debounce.js";
import { router, Link } from "@inertiajs/vue3";
import PaginationLink from "@/Components/Table/PaginationLink.vue";
import BaseDropDown from "@/Components/Forms/BaseDropDown.vue";
import BaseInput from "@/Components/Forms/BaseInput.vue";

const props = defineProps({
    vacancies: {
        type: Object,
        default: () => ({ data: [] })
    },
    filter: Object,
    company: {
        type: Array
    }
});

const searchInput = ref(props.filter.search || '');
const filterCompany = ref(props.filter.company || '');
const filterStatus = computed(() => {
    return props.filter.status || '';
});

const pageTitle = computed(() => {
    return props.filter.status === 'applied' ? 'Lowongan Dilamar' : 'Lowongan Tersedia';
});

watch([
    searchInput,
    filterCompany
], debounce(() => {
    const query = {};
    if (searchInput.value) query.search = searchInput.value;
    if (filterCompany.value) query.company = filterCompany.value;
    if (filterStatus.value) query.status = filterStatus.value;
    router.get(`/user/job?${new URLSearchParams(query).toString()}`);
}, 500));

function formatDate(dateStr) {
    const date = new Date(dateStr);
    return date.toLocaleDateString('id-ID', {
        year: 'numeric',
        month: 'long',
        day: 'numeric'
    });
}
</script>
